@@ -87,11 +87,12 @@ static inline bool ffReadFileBufferRelative(FFNativeFD dfd, const char* fileName
 }
 
 //Bit flags, combine with |
-typedef enum FFPathType
+typedef enum __attribute__((__packed__)) FFPathType
 {
     FF_PATHTYPE_FILE = 1 << 0,
     FF_PATHTYPE_DIRECTORY = 1 << 1,
     FF_PATHTYPE_ANY = FF_PATHTYPE_FILE | FF_PATHTYPE_DIRECTORY,
+    FF_PATHTYPE_FORCE_UNSIGNED = UINT8_MAX,
 } FFPathType;
 
 static inline bool ffPathExists(const char* path, FFPathType pathType)
@@ -118,22 +119,17 @@ static inline bool ffPathExists(const char* path, FFPathType pathType)
     }
     else
     {
-        size_t len = strlen(path);
-        assert(len < PATH_MAX);
-        if (len == 0) return false;
+        struct stat fileStat;
+        if(stat(path, &fileStat) != 0)
+            return false;
 
-        int ret;
-        if (path[len - 1] != '/')
-        {
-            char buf[PATH_MAX + 1];
-            memcpy(buf, path, len);
-            buf[len] = '/';
-            buf[len + 1] = 0;
-            ret = access(buf, F_OK);
-        }
-        else
-            ret = access(path, F_OK);
-        return pathType == FF_PATHTYPE_DIRECTORY ? ret == 0 : ret == -1 && errno == ENOTDIR;
+        unsigned int mode = fileStat.st_mode & S_IFMT;
+
+        if(pathType & FF_PATHTYPE_FILE && mode != S_IFDIR)
+            return true;
+
+        if(pathType & FF_PATHTYPE_DIRECTORY && mode == S_IFDIR)
+            return true;
     }
 
     #endif
