@@ -8,7 +8,6 @@
 #ifdef __NetBSD__
 #include <sys/types.h>
 #include <sys/statvfs.h>
-#define getfsstat(...) getvfsstat(__VA_ARGS__)
 #define statfs statvfs
 #define f_flags f_flag
 #define f_bsize f_frsize
@@ -37,7 +36,7 @@ static const char* detectFsLabel(struct statfs* fs, FFDisk* disk)
             return "geom_gettree() failed";
         }
 
-        for (cLabels = geomTree.lg_class.lh_first; !ffStrEquals(cLabels->lg_name, "LABEL"); cLabels = cLabels->lg_class.le_next);
+        for (cLabels = geomTree.lg_class.lh_first; cLabels && !ffStrEquals(cLabels->lg_name, "LABEL"); cLabels = cLabels->lg_class.le_next);
         if (!cLabels)
             return "Class LABEL is not found";
     }
@@ -125,18 +124,26 @@ static void detectFsInfo(struct statfs* fs, FFDisk* disk)
 
 const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
 {
+    #ifndef __NetBSD__
     int size = getfsstat(NULL, 0, MNT_WAIT);
-
-    if(size <= 0)
-        return "getfsstat(NULL, 0, MNT_WAIT) failed";
+    if(size <= 0) return "getfsstat(NULL, 0, MNT_WAIT) failed";
+    #else
+    int size = getvfsstat(NULL, 0, ST_WAIT);
+    if(size <= 0) return "getvfsstat(NULL, 0, ST_WAIT) failed";
+    #endif
 
     FF_AUTO_FREE struct statfs* buf = malloc(sizeof(*buf) * (unsigned) size);
+    #ifndef __NetBSD__
     if(getfsstat(buf, (int) (sizeof(*buf) * (unsigned) size), MNT_NOWAIT) <= 0)
         return "getfsstat(buf, size, MNT_NOWAIT) failed";
+    #else
+    if(getvfsstat(buf, sizeof(*buf) * (unsigned) size, ST_NOWAIT) <= 0)
+        return "getvfsstat(buf, size, ST_NOWAIT) failed";
+    #endif
 
     for(struct statfs* fs = buf; fs < buf + size; ++fs)
     {
-        if(__builtin_expect(options->folders.length, 0))
+        if(__builtin_expect(options->folders.length > 0, 0))
         {
             if(!ffDiskMatchMountpoint(options, fs->f_mntonname))
                 continue;
@@ -158,7 +165,7 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
         disk->bytesUsed = 0; // To be filled in ./disk.c
 
         disk->filesTotal = (uint32_t) fs->f_files;
-        disk->filesUsed = (uint32_t) (disk->filesTotal - (uint64_t)fs->f_ffree);
+        disk->filesUsed = (uint32_t) (fs->f_files - fs->f_ffree);
 
         ffStrbufInitS(&disk->mountFrom, fs->f_mntfromname);
         ffStrbufInitS(&disk->mountpoint, fs->f_mntonname);
@@ -178,7 +185,7 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
         #ifndef __DragonFly__
         struct stat st;
         if(stat(fs->f_mntonname, &st) == 0 && st.st_birthtimespec.tv_sec > 0)
-            disk->createTime = (uint64_t)((st.st_birthtimespec.tv_sec * 1000) + (st.st_birthtimespec.tv_nsec / 1000000));
+            disk->createTime = (uint64_t)(((uint64_t) st.st_birthtimespec.tv_sec * 1000) + ((uint64_t) st.st_birthtimespec.tv_nsec / 1000000));
         #endif
     }
 
