@@ -14,6 +14,9 @@
     #include <sys/sysctl.h>
 #elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
     #include <sys/sysctl.h>
+#elif defined(__HAIKU__)
+    #include <image.h>
+    #include <OS.h>
 #endif
 
 static void getExePath(FFPlatform* platform)
@@ -21,7 +24,8 @@ static void getExePath(FFPlatform* platform)
     char exePath[PATH_MAX + 1];
     #ifdef __linux__
         ssize_t exePathLen = readlink("/proc/self/exe", exePath, sizeof(exePath) - 1);
-        exePath[exePathLen] = '\0';
+        if (exePathLen >= 0)
+            exePath[exePathLen] = '\0';
     #elif defined(__APPLE__)
         int exePathLen = proc_pidpath((int) getpid(), exePath, sizeof(exePath));
     #elif defined(__FreeBSD__) || defined(__NetBSD__)
@@ -44,7 +48,19 @@ static void getExePath(FFPlatform* platform)
         size_t exePathLen = 0;
     #elif defined(__sun)
         ssize_t exePathLen = readlink("/proc/self/path/a.out", exePath, sizeof(exePath) - 1);
-        exePath[exePathLen] = '\0';
+        if (exePathLen >= 0)
+            exePath[exePathLen] = '\0';
+    #elif defined(__HAIKU__)
+        size_t exePathLen = 0;
+        image_info info;
+        int32 cookie = 0;
+
+        while (get_next_image_info(B_CURRENT_TEAM, &cookie, &info) == B_OK) {
+            if (info.type == B_APP_IMAGE) {
+                exePathLen = strlcpy(exePath, info.name, PATH_MAX);
+                break;
+            }
+        }
     #endif
     if (exePathLen > 0)
     {
@@ -107,6 +123,7 @@ static void getCacheDir(FFPlatform* platform)
 
 static void getConfigDirs(FFPlatform* platform)
 {
+    // Always make sure `${XDG_CONFIG_HOME:-$HOME/.config}` is the first entry
     platformPathAddEnv(&platform->configDirs, "XDG_CONFIG_HOME");
     ffPlatformPathAddHome(&platform->configDirs, platform, ".config/");
 
@@ -114,6 +131,9 @@ static void getConfigDirs(FFPlatform* platform)
         ffPlatformPathAddHome(&platform->configDirs, platform, "Library/Preferences/");
         ffPlatformPathAddHome(&platform->configDirs, platform, "Library/Application Support/");
     #endif
+    #if defined(__HAIKU__)
+        ffPlatformPathAddHome(&platform->configDirs, platform, "config/settings/");
+    #endif
 
     ffPlatformPathAddHome(&platform->configDirs, platform, "");
     platformPathAddEnv(&platform->configDirs, "XDG_CONFIG_DIRS");
@@ -152,6 +172,14 @@ static void getDataDirs(FFPlatform* platform)
 #endif
     ffPlatformPathAddAbsolute(&platform->dataDirs, FASTFETCH_TARGET_DIR_USR "/local/share/");
     ffPlatformPathAddAbsolute(&platform->dataDirs, FASTFETCH_TARGET_DIR_USR "/share/");
+
+    if (platform->exePath.length > 0)
+    {
+        // Add ${currentExePath}
+        FF_STRBUF_AUTO_DESTROY path = ffStrbufCreateCopy(&platform->exePath);
+        ffStrbufSubstrBeforeLastC(&path, '/');
+        ffPlatformPathAddAbsolute(&platform->dataDirs, path.chars);
+    }
 }
 
 static void getUserName(FFPlatform* platform, const struct passwd* pwd)
@@ -182,6 +210,12 @@ static void getSysinfo(FFPlatformSysinfo* info, const struct utsname* uts)
     ffStrbufAppendS(&info->name, uts->sysname);
     ffStrbufAppendS(&info->release, uts->release);
     ffStrbufAppendS(&info->version, uts->version);
+    #ifdef __HAIKU__
+    /* historical reason */
+    if (ffStrEquals(uts->machine, "BePC"))
+        ffStrbufSetStatic(&info->architecture, "i386");
+    else
+    #endif
     ffStrbufAppendS(&info->architecture, uts->machine);
     ffStrbufInit(&info->displayVersion);
 
